import spidev
import RPi.GPIO as GPIO
import time

# Initialize SPI communication
spi = spidev.SpiDev()
spi.open(0, 1)  # SPI bus 0, device 0
spi.max_speed_hz = 50000  # Set SPI speed (specific speed depends on the situation)

# Set up GPIO
GPIO.setmode(GPIO.BCM)
GPIO.setup(17, GPIO.IN)  # Touch interrupt pin, assumed to be connected to GPIO17

# Define control commands for the XPT1040 (specific commands can be found in the chip datasheet)
COMMAND_X = 0x90  # Command to read X coordinate
COMMAND_Y = 0xD0  # Command to read Y coordinate

# Read touch data
def read_touch_data():
    # Read X coordinate
    x_response = spi.xfer2([COMMAND_X, 0x00])
    x = ((x_response[0] & 0x0F) << 8) | x_response[1]
    
    # Read Y coordinate
    y_response = spi.xfer2([COMMAND_Y, 0x00])
    y = ((y_response[0] & 0x0F) << 8) | y_response[1]
    
    return x, y

# Main function, continuously read touch coordinates
def main():
    while True:
        if GPIO.input(17) == GPIO.LOW:  # Check if the interrupt pin is low (indicating a touch event)
            print("Touch detected!")
            x, y = read_touch_data()
            print(f"Touch Coordinates: X = {x}, Y = {y}")
        else:
            print("No touch detected")
        
        time.sleep(0.1)  # Delay

if __name__ == "__main__":
    main()
